@@ -10,8 +10,8 @@ static const struct stlink_chipid_params devices[] = {
             .flash_size_reg = 0x1ff0f442,      // section 45.2
             .flash_pagesize = 0x800,           // No flash pages
             .sram_size = 0x80000,              // "SRAM" byte size in hex from
-            .bootrom_base = 0x00200000,        //! "System memory" starting address from 
-            .bootrom_size = 0xEDC0             //! @todo "System memory" byte size in hex from 
+            .bootrom_base = 0x00200000,        //! "System memory" starting address from
+            .bootrom_size = 0xEDC0             //! @todo "System memory" byte size in hex from
         },
         {
             //RM0385 and DS10916 document was used to find these paramaters
@@ -432,7 +432,7 @@ static const struct stlink_chipid_params devices[] = {
             .chip_id = STLINK_CHIPID_STM32_L4,
             .description = "L4 device",
             .flash_type = STLINK_FLASH_TYPE_L4,
-            .flash_size_reg = 0x1fff75e0,    // "Flash size data register" (sec 45.2, page 1671)
+            .flash_size_reg = 0x1FFF75e0,    // "Flash size data register" (sec 45.2, page 1671)
             .flash_pagesize = 0x800,         // 2K (sec 3.2, page 78; also appears in sec 3.3.1 and tables 4-6 on pages 79-81)
             // SRAM1 is "up to" 96k in the standard Cortex-M memory map;
             // SRAM2 is 32k mapped at at 0x10000000 (sec 2.3, page 73 for
@@ -441,6 +441,18 @@ static const struct stlink_chipid_params devices[] = {
             .bootrom_base = 0x1fff0000,      // Tables 4-6, pages 80-81 (Bank 1 system memory)
             .bootrom_size = 0x7000           // 28k (per bank), same source as base
         },
+        {
+            // STM32L4RX
+            // From DM00310109.pdf
+            .chip_id = STLINK_CHIPID_STM32_L4RX,
+            .description = "L4Rx device",
+            .flash_type = STLINK_FLASH_TYPE_L4,
+            .flash_size_reg = 0x1fff75e0,    // "Flash size data register" (sec 52.2, page 2049)
+            .flash_pagesize = 0x1000,        // 4k, section 3.3, pg 97
+            .sram_size = 0xa0000,            // 192k (SRAM1) + 64k SRAM2 + 384k SRAM3 = 640k, or 0xA0000
+            .bootrom_base = 0x1fff0000,      // 3.3.1, pg 99
+            .bootrom_size = 0x7000           // 28k (per bank), same source as base (pg 99)
+        },
         {
             // STLINK_CHIPID_STM32_L43X
             // From RM0392.
